void parsing(int size, unsigned char *buf, struct phone_table_entry *pte, struct sockaddr_in *addr_from);
void SendPing(struct phone_table_entry *pte);
void SendRetransmit(struct phone_table_entry *pte);
void SendFavorite(unsigned char pos, unsigned char status, struct phone_table_entry *pte, char *text);

extern DWORD dwTimeOut;

#define MAX_BUF_SIZE	64		// Size of the transmit buffer
#define MAX_BUF_NUMBER	30		// Number of slots for the transmit queue
#define MAX_PHONE		64		// Max number of phone
#define PING_TIMER		60000	// Ping every x milliseconds
#define NB_MAX_RETRANSMIT 8		// Try x times before removing the phone
#define RETRANSMIT_TIMER 2000	// Wait x milliseconds before resending a packet
#define MAC_DB			"db_mac.txt"

/* Format of db_mac.txt :

  format for mac addr : space separator + lower case

  <mac currnt phone><long name of the owner>< mac favorite #1>< mac favorite #2>< mac favorite #3>< mac favorite #4>< mac favorite #5><name fv0><name fv1><name fv2><name fv3><name fv4><name fv5>
  00 60 38 01 02 03       Owner NAME        00 60 38 01 02 02 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 Favorite1 Bluuu     test                                    
  <    18 bytes    ><        24 bytes      ><    18 bytes    ><    18 bytes    ><    18 bytes    ><    18 bytes    ><    18 bytes    ><10 bytes><10 bytes><10 bytes><10 bytes><10 bytes><10 bytes>
  total length = 192 bytes + \n (\r?)
*/
enum PhoneState {
	STATE_INIT,
	STATE_AUTHDENY,
	STATE_MAINPAGE,
	STATE_DIALPAGE,
	STATE_DIALING,
	STATE_RINGING,
	STATE_CALL,
	STATE_BADNUMBER
};

enum ReceiverState {
	STATE_HANGUP,
	STATE_PICKUP_NOSPEAKER,
	STATE_NOPICKUP_SPEAKER,
	STATE_PICKUP_SPEAKER
};

enum PhoneKey {
	KEY_0		= 0x40,
	KEY_1		= 0x41,
	KEY_2		= 0x42,
	KEY_3		= 0x43,
	KEY_4		= 0x44,
	KEY_5		= 0x45,
	KEY_6		= 0x46,
	KEY_7		= 0x47,
	KEY_8		= 0x48,
	KEY_9		= 0x49,
	KEY_STAR	= 0x4a,
	KEY_SHARP	= 0x4b,
	KEY_UP		= 0x4c,
	KEY_DOWN	= 0x4d,
	KEY_RIGHT	= 0x4e,
	KEY_LEFT	= 0x4f,
	KEY_QUIT	= 0x50,
	KEY_COPY	= 0x51,
	KEY_FUNC1	= 0x54,
	KEY_FUNC2	= 0x55,
	KEY_FUNC3	= 0x56,
	KEY_FUNC4	= 0x57,
	KEY_WAIT	= 0x5b,
	KEY_HANGUP	= 0x5c,
	KEY_MUTE	= 0x5d,
	KEY_HEADPHN = 0x5e,
	KEY_LOUDSPK = 0x5f,
	KEY_FAV0	= 0x60,
	KEY_FAV1	= 0x61,
	KEY_FAV2	= 0x62,
	KEY_FAV3	= 0x63,
	KEY_FAV4	= 0x64,
	KEY_FAV5	= 0x65,
	KEY_COMPUTR	= 0x7b,
	KEY_CONF	= 0x7c,
	KEY_SNDHIST = 0x7d,
	KEY_RCVHIST = 0x7e,
	KEY_INDEX	= 0x7f
};
struct phone_entry {
	unsigned short seq_phone;					// sequence number for the next packet (when we receive a request)
	unsigned short seq_server;					// sequence number for the next packet (when we send a request)
	unsigned short last_seq_ack;				// sequence number of the last ACK received
	unsigned long tick_next_ping;				// time for the next ping
	int		last_buf_available;					// number of a free slot
	int		nb_retransmit;						// number of retransmition
	int		state;								// state of the phone (see PhoneState)
	int		receiver_state;						// state of the receiver (see ReceiverState)
	int		size_phone_number;					// size of the phone number
	char	phone_number[16];					// the phone number entered by the user
	char	mac_current[18];					// mac address of the current phone in ascii
	char	mac_fav[6][18];						// mac address of the favorites phones in ascii
	char	name_fav[6][11];					// short name for the favorites phones in ascii
	char	name_current[25];					// name of the owner of the current phone in ascii
	struct	phone_table_entry *pte_peer;		// Pointer to the structure of the caller or the called phone
	WSABUF	wsabufsend[MAX_BUF_NUMBER];			// Size of each paquet stored in the buffer array & pointer to this buffer
	WSAOVERLAPPED wsaoverlap[MAX_BUF_NUMBER];	// Structure used for overlapped socket
	char	buf[MAX_BUF_SIZE][MAX_BUF_NUMBER];	// Buffer array used to keep the lastest non-acked paquets
};

struct phone_table_entry {
	struct sockaddr_in addr_from;	// IP address of the phone
	DWORD timeout;					// time-out : resend packet if no ack was received before the timeout occured
	struct phone_entry *ptr_phone_entry;
};

/*
case KEY_0 :
case KEY_1 :
case KEY_2 :
case KEY_3 :
case KEY_4 :
case KEY_5 :
case KEY_6 :
case KEY_7 :
case KEY_8 :
case KEY_9 :
case KEY_STAR :
case KEY_SHARP :
case KEY_UP :
case KEY_DOWN :
case KEY_RIGHT :
case KEY_LEFT :
case KEY_QUIT :
case KEY_COPY :
case KEY_FUNC1 :
case KEY_FUNC2 :
case KEY_FUNC3 :
case KEY_FUNC4 :
case KEY_WAIT :
case KEY_HANGUP :
case KEY_MUTE :
case KEY_HEADPHN :
case KEY_LOUDSPK :
case KEY_FAV0 :
case KEY_FAV1 :
case KEY_FAV2 :
case KEY_FAV3 :
case KEY_FAV4 :
case KEY_FAV5 :
case KEY_COMPUTR :
case KEY_CONF :
case KEY_SNDHIST :
case KEY_RCVHIST :
case KEY_INDEX :
*/
